#define GOPHER_DIR "/var/gopher/"
#define GOPHER_USER "gopher"
#define GOPHER_GROUP "gopher"
#define LOGLEVEL DEBUG

// Windows can't understand low ports because you won't be root.
#ifndef _WIN32
#define GOPHER_PORT "70"
#else
#define GOPHER_PORT "7070"
#endif // _WIN32

/*
 * For your reference, the relevant Gopher file types. Only 0 and 9 are supported right now:
 * 0: text file
 * 5: a dos/windows executable
 * 6: binary file (uuencoded)
 * 9: generic binary file
 * g: gif
 * I: image (not necessarily a gif)
 */

static const struct mapping mappings[] = {
    {.extension = ".tar.gz", .filetype = '9'},
    {.extension = ".tar.xz", .filetype = '9'},
    {.extension = ".tar",    .filetype = '9'},
    {.extension = ".txt",    .filetype = '0'},
    {.extension = ".map",    .filetype = '1'},
    {.extension = ".jpg",    .filetype = 'I'},
    {.extension = ".jpeg",    .filetype = 'I'},
    {.extension = ".png",    .filetype = 'I'},
    {.extension = ".JPG",    .filetype = 'I'}
};
